# GeomEffiBEM


[![pypi](https://img.shields.io/pypi/v/geomeffibem.svg)](https://pypi.org/project/geomeffibem/)
[![python](https://img.shields.io/pypi/pyversions/geomeffibem.svg)](https://pypi.org/project/geomeffibem/)
[![Build Status](https://github.com/jmarrec/geomeffibem/actions/workflows/dev.yml/badge.svg)](https://github.com/jmarrec/geomeffibem/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/jmarrec/geomeffibem/branch/main/graphs/badge.svg)](https://codecov.io/github/jmarrec/geomeffibem)


A small library to facilitate some building energy modeling geometry operations with OpenStudio and EnergyPlus in mind

A Jupyter Notebook[GeoEffiBEM_Demonstration.ipynb](GeomEffiBEM_Demonstation.ipynb) can serve as a small demonstration of the features.


* Documentation: <https://jmarrec.github.io/geomeffibem>
* GitHub: <https://github.com/jmarrec/geomeffibem>
* PyPI: <https://pypi.org/project/geomeffibem/>
* Free software: MIT
